@@ -10,8 +10,12 @@ class MockM:
         args = self.get_mocker_params_to_tuple(mock_str)
         if keyword == 'date':
             return m_random.m_date.date(*args)
+        elif keyword == 'datetime':
+            return m_random.m_date.datetime(*args)
         elif keyword == 'time':
             return m_random.m_date.time(*args)
+        elif keyword == 'now':
+            return m_random.m_date.now(*args)
         elif keyword == 'float':
             return m_random.m_float.float(*args)
         elif keyword == 'natural':
@@ -32,6 +36,12 @@ class MockM:
             return m_random.m_name.clast(*args)
         elif keyword == 'cname':
             return m_random.m_name.cname(*args)
+        elif keyword == 'first':
+            return m_random.m_name.first(*args)
+        elif keyword == 'last':
+            return m_random.m_name.last(*args)
+        elif keyword == 'name':
+            return m_random.m_name.name(*args)
 
     @classmethod
     def get_mocker_key(cls, mock_str):
