@@ -3,7 +3,9 @@ import re
 import string
 from datetime import datetime, timedelta
 
-from x_mock.m_chinese_source import single_family_name
+from dateutil.relativedelta import relativedelta
+
+from x_mock.m_random_source import single_family_name, en_family_name, en_name
 
 
 def inNone(obj):
@@ -24,13 +26,16 @@ def tuple_to_str(objects) -> str:
     return str(''.join(objects))
 
 
-def shuffle_string(strings):
+def shuffle_string(strings) -> str:
     """
 
-    :param strings: 被打乱的字符
+    :param strings: 被打乱的字符(str/list/tuple)
     :return: 打乱的字符
     """
-    strings = list(strings)
+    if isinstance(strings, (list, tuple)):
+        pass
+    elif isinstance(strings, str):
+        strings = list(strings)
     random.shuffle(strings)
     strings = ''.join(strings)
     return strings
@@ -53,48 +58,56 @@ class MockPyExpressionException(Exception):
 
 _mock_exception = MockPyExpressionException()
 
-chinese = '一乙二十丁厂七卜人入八九几儿了力乃刀又三于干亏士工土才寸下大丈与万上小口巾山千乞川亿个勺久凡及夕丸么广亡门义之尸弓己已' \
-          '子卫也女飞刃习叉马乡丰王井开夫天无元专云扎艺木五支厅不太犬区历尤友匹车巨牙屯比互切瓦止少日中冈贝内水见午牛手毛气升长仁' \
-          '什片仆化仇币仍仅斤爪反介父从今凶分乏公仓月氏勿欠风丹匀乌凤勾文六方火为斗忆订计户认心尺引丑巴孔队办以允予劝双书幻玉刊示末' \
-          '未击打巧正扑扒功扔去甘世古节本术可丙左厉右石布龙平灭轧东卡北占业旧帅归且旦目叶甲申叮电号田由史只央兄叼叫另叨叹四生失禾丘' \
-          '付仗代仙们仪白仔他斥瓜乎丛令用甩印乐句匆册犯外处冬鸟务包饥主市立闪兰半汁汇头汉宁穴它讨写让礼训必议讯记永司尼民出辽奶奴加' \
-          '召皮边发孕圣对台矛纠母幼丝式刑动扛寺吉扣考托老执巩圾扩扫地扬场耳共芒亚芝朽朴机权过臣再协西压厌在有百存而页匠夸夺灰达列死' \
-          '成夹轨邪划迈毕至此贞师尘尖劣光当早吐吓虫曲团同吊吃因吸吗屿帆岁回岂刚则肉网年朱先丢舌竹迁乔伟传乒乓休伍伏优伐延件任伤价份' \
-          '华仰仿伙伪自血向似后行舟全会杀合兆企众爷伞创肌朵杂危旬旨负各名多争色壮冲冰庄庆亦刘齐交次衣产决充妄闭问闯羊并关米灯州汗污' \
-          '江池汤忙兴宇守宅字安讲军许论农讽设访寻那迅尽导异孙阵阳收阶阴防奸如妇好她妈戏羽观欢买红纤级约纪驰巡寿弄麦形进戒吞远违运扶' \
-          '抚坛技坏扰拒找批扯址走抄坝贡攻赤折抓扮抢孝均抛投坟抗坑坊抖护壳志扭块声把报却劫芽花芹芬苍芳严芦劳克苏杆杠杜材村杏极李杨求' \
-          '更束豆两丽医辰励否还歼来连步坚旱盯呈时吴助县里呆园旷围呀吨足邮男困吵串员听吩吹呜吧吼别岗帐财针钉告我乱利秃秀私每兵估体何' \
-          '但伸作伯伶佣低你住位伴身皂佛近彻役返余希坐谷妥含邻岔肝肚肠龟免狂犹角删条卵岛迎饭饮系言冻状亩况床库疗应冷这序辛弃冶忘闲间' \
-          '闷判灶灿弟汪沙汽沃泛沟没沈沉怀忧快完宋宏牢究穷灾良证启评补初社识诉诊词译君灵即层尿尾迟局改张忌际陆阿陈阻附妙妖妨努忍劲鸡' \
-          '驱纯纱纳纲驳纵纷纸纹纺驴纽奉玩环武青责现表规抹拢拔拣担坦押抽拐拖拍者顶拆拥抵拘势抱垃拉拦拌幸招坡披拨择抬其取苦若茂苹苗英' \
-          '范直茄茎茅林枝杯柜析板松枪构杰述枕丧或画卧事刺枣雨卖矿码厕奔奇奋态欧垄妻顷转斩轮软到非叔肯齿些虎虏肾贤尚旺具果味昆国昌畅' \
-          '明易昂典固忠咐呼鸣咏呢岸岩帖罗帜岭凯败贩购图钓制知垂牧物乖刮秆和季委佳侍供使例版侄侦侧凭侨佩货依的迫质欣征往爬彼径所舍金' \
-          '命斧爸采受乳贪念贫肤肺肢肿胀朋股肥服胁周昏鱼兔狐忽狗备饰饱饲变京享店夜庙府底剂郊废净盲放刻育闸闹郑券卷单炒炊炕炎炉沫浅法' \
-          '泄河沾泪油泊沿泡注泻泳泥沸波泼泽治怖性怕怜怪学宝宗定宜审宙官空帘实试郎诗肩房诚衬衫视话诞询该详建肃录隶居届刷屈弦承孟孤陕' \
-          '降限妹姑姐姓始驾参艰线练组细驶织终驻驼绍经贯奏春帮珍玻毒型挂封持项垮挎城挠政赴赵挡挺括拴拾挑指垫挣挤拼挖按挥挪某甚革荐巷' \
-          '带草茧茶荒茫荡荣故胡南药标枯柄栋相查柏柳柱柿栏树要咸威歪研砖厘厚砌砍面耐耍牵残殃轻鸦皆背战点临览竖省削尝是盼眨哄显哑冒映' \
-          '星昨畏趴胃贵界虹虾蚁思蚂虽品咽骂哗咱响哈咬咳哪炭峡罚贱贴骨钞钟钢钥钩卸缸拜看矩怎牲选适秒香种秋科重复竿段便俩贷顺修保促侮' \
-          '俭俗俘信皇泉鬼侵追俊盾待律很须叙剑逃食盆胆胜胞胖脉勉狭狮独狡狱狠贸怨急饶蚀饺饼弯将奖哀亭亮度迹庭疮疯疫疤姿亲音帝施闻阀阁' \
-          '差养美姜叛送类迷前首逆总炼炸炮烂剃洁洪洒浇浊洞测洗活派洽染济洋洲浑浓津恒恢恰恼恨举觉宣室宫宪突穿窃客冠语扁袄祖神祝误诱说' \
-          '诵垦退既屋昼费陡眉孩除险院娃姥姨姻娇怒架贺盈勇怠柔垒绑绒结绕骄绘给络骆绝绞统耕耗艳泰珠班素蚕顽盏匪捞栽捕振载赶起盐捎捏埋' \
-          '捉捆捐损都哲逝捡换挽热恐壶挨耻耽恭莲莫荷获晋恶真框桂档桐株桥桃格校核样根索哥速逗栗配翅辱唇夏础破原套逐烈殊顾轿较顿毙致柴' \
-          '桌虑监紧党晒眠晓鸭晃晌晕蚊哨哭恩唤啊唉罢峰圆贼贿钱钳钻铁铃铅缺氧特牺造乘敌秤租积秧秩称秘透笔笑笋债借值倚倾倒倘俱倡候俯倍' \
-          '倦健臭射躬息徒徐舰舱般航途拿爹爱颂翁脆脂胸胳脏胶脑狸狼逢留皱饿恋桨浆衰高席准座脊症病疾疼疲效离唐资凉站剖竞部旁旅畜阅羞瓶' \
-          '兼烤烘烦烧烛烟递涛浙涝酒涉消浩海涂浴浮流润浪浸涨烫涌悟悄悔悦害宽家宵宴宾窄容宰案请朗诸读扇袜袖袍被祥课谁调冤谅谈谊剥恳展' \
-          '弱陵陶陷陪娱娘通能难预桑绢绣验继球理捧堵描域掩捷排掉堆推掀授教掏掠培接控探据掘职基著勒黄萌萝菌菜萄菊萍菠营械梦梢梅检梳梯' \
-          '副票戚爽聋袭盛雪辅辆虚雀堂常匙晨睁眯眼悬野啦晚啄距跃略蛇累唱患唯崖崭崇圈铜铲银甜梨犁移笨笼笛符第敏做袋悠偿偶偷您售停偏假' \
-          '盘船斜盒鸽悉欲彩领脚脖脸脱象够猜猪猎猫猛馅馆凑减毫麻痒痕廊康庸鹿盗章竟商族旋望率着盖粘粗粒断剪兽清添淋淹渠渐混渔淘液淡深' \
-          '渗情惜惭悼惧惕惊惨惯寇寄宿窑密谋谎祸谜逮敢屠弹随蛋隆隐婚婶颈绩绪续骑绳维绵绸绿琴斑替款堪搭塔越趁趋超提堤博揭喜插揪搜煮援' \
-          '搂搅握揉斯期欺联散惹葬葛董葡敬葱落朝辜葵棒棋植森椅椒棵棍棉棚棕惠惑逼厨厦硬确雁殖裂雄暂雅辈悲紫辉敞赏掌晴暑最量喷晶喇遇喊' \
-          '跌跑遗蛙蛛蜓喝喂喘喉幅帽赌赔黑铸铺链销锁锄锅锈锋锐短智毯鹅剩稍程稀税筐等筑策筛筒答筋筝傲傅牌堡集焦傍储奥街惩御循艇舒番释' \
-          '脾腔鲁猾猴然馋装蛮就痛童阔善羡普粪尊道曾焰港湖渣湿温渴滑湾渡游滋溉愤慌惰愧愉慨割寒富窜窝窗遍裕裤裙谢谣谦属屡强粥疏隔隙絮' \
-          '缎缓编骗缘瑞魂肆摄摸填搏塌鼓摆携搬摇搞塘摊蒜勤鹊蓝墓幕蓬蓄蒙蒸献禁楚想槐榆楼概赖酬感碍碑碎碰碗碌雷零雾雹输督龄鉴睛睡睬鄙' \
-          '盟歇暗照跨跳跪路跟遣蛾蜂嗓置罪罩错锡锣锤锦键锯矮辞稠愁筹签简毁舅鼠催傻像躲微愈遥腰腥腹腾腿触解酱痰廉新韵意粮数煎塑慈煤煌' \
-          '源滤滥滔溪溜滚滨粱滩慎誉塞谨福群殿辟障嫌嫁叠缝缠静碧璃墙撇嘉摧截誓境摘摔聚蔽慕暮蔑模榴榜榨歌遭酷酿酸磁愿需弊裳颗嗽蜻蜡蝇' \
-          '锹锻舞稳算箩管僚鼻魄貌膜膊膀鲜疑馒裹敲豪膏遮腐瘦辣竭端旗精歉熄熔漆漂漫滴演漏慢寨赛察蜜谱嫩翠熊凳骡缩慧撕撒趣趟撑播撞撤增' \
-          '蕉蔬横槽樱橡飘醋醉震霉瞒题暴瞎影踢踏踩踪蝶蝴嘱墨镇靠稻黎稿稼箱箭篇僵躺僻德艘膝膛熟摩颜毅糊遵潜潮懂额慰劈操燕薯薪薄颠橘整' \
-          '餐嘴蹄器赠默镜赞篮邀衡膨雕磨凝辨辩糖糕燃澡激懒壁避缴戴擦鞠藏霜霞瞧蹈螺穗繁辫赢糟糠燥臂翼骤鞭覆蹦镰翻鹰警攀蹲颤瓣爆疆壤耀' \
-          '嚷籍魔灌蠢霸露料益拳粉剧屑桶救得衔婆梁裁搁景践禽腊嫂登愚暖满漠蜘赚聪鞋融醒躁嚼'
+chinese = "一乙二十丁厂七卜人入八九几儿了力乃刀又三于干亏士工土才寸下大丈与万上小口巾山千乞川亿个勺久凡及夕丸么" \
+          "广亡门义之尸弓己已子卫也女飞刃习叉马乡丰王井开夫天无元专云扎艺木五支厅不太犬区历尤友匹车巨牙屯比互切" \
+          "瓦止少日中冈贝内水见午牛手毛气升长仁什片仆化仇币仍仅斤爪反介父从今凶分乏公仓月氏勿欠风丹匀乌凤勾文六" \
+          "方火为斗忆订计户认心尺引丑巴孔队办以允予劝双书幻玉刊示末未击打巧正扑扒功扔去甘世古节本术可丙左厉右石" \
+          "布龙平灭轧东卡北占业旧帅归且旦目叶甲申叮电号田由史只央兄叼叫另叨叹四生失禾丘付仗代仙们仪白仔他斥瓜乎" \
+          "丛令用甩印乐句匆册犯外处冬鸟务包饥主市立闪兰半汁汇头汉宁穴它讨写让礼训必议讯记永司尼民出辽奶奴加召皮" \
+          "边发孕圣对台矛纠母幼丝式刑动扛寺吉扣考托老执巩圾扩扫地扬场耳共芒亚芝朽朴机权过臣再协西压厌在有百存而" \
+          "页匠夸夺灰达列死成夹轨邪划迈毕至此贞师尘尖劣光当早吐吓虫曲团同吊吃因吸吗屿帆岁回岂刚则肉网年朱先丢舌" \
+          "竹迁乔伟传乒乓休伍伏优伐延件任伤价份华仰仿伙伪自血向似后行舟全会杀合兆企众爷伞创肌朵杂危旬旨负各名多" \
+          "争色壮冲冰庄庆亦刘齐交次衣产决充妄闭问闯羊并关米灯州汗污江池汤忙兴宇守宅字安讲军许论农讽设访寻那迅尽" \
+          "导异孙阵阳收阶阴防奸如妇好她妈戏羽观欢买红纤级约纪驰巡寿弄麦形进戒吞远违运扶抚坛技坏扰拒找批扯址走抄" \
+          "坝贡攻赤折抓扮抢孝均抛投坟抗坑坊抖护壳志扭块声把报却劫芽花芹芬苍芳严芦劳克苏杆杠杜材村杏极李杨求更束" \
+          "豆两丽医辰励否还歼来连步坚旱盯呈时吴助县里呆园旷围呀吨足邮男困吵串员听吩吹呜吧吼别岗帐财针钉告我乱利" \
+          "秃秀私每兵估体何但伸作伯伶佣低你住位伴身皂佛近彻役返余希坐谷妥含邻岔肝肚肠龟免狂犹角删条卵岛迎饭饮系" \
+          "言冻状亩况床库疗应冷这序辛弃冶忘闲间闷判灶灿弟汪沙汽沃泛沟没沈沉怀忧快完宋宏牢究穷灾良证启评补初社识" \
+          "诉诊词译君灵即层尿尾迟局改张忌际陆阿陈阻附妙妖妨努忍劲鸡驱纯纱纳纲驳纵纷纸纹纺驴纽奉玩环武青责现表规" \
+          "抹拢拔拣担坦押抽拐拖拍者顶拆拥抵拘势抱垃拉拦拌幸招坡披拨择抬其取苦若茂苹苗英范直茄茎茅林枝杯柜析板松" \
+          "枪构杰述枕丧或画卧事刺枣雨卖矿码厕奔奇奋态欧垄妻顷转斩轮软到非叔肯齿些虎虏肾贤尚旺具果味昆国昌畅明易" \
+          "昂典固忠咐呼鸣咏呢岸岩帖罗帜岭凯败贩购图钓制知垂牧物乖刮秆和季委佳侍供使例版侄侦侧凭侨佩货依的迫质欣" \
+          "征往爬彼径所舍金命斧爸采受乳贪念贫肤肺肢肿胀朋股肥服胁周昏鱼兔狐忽狗备饰饱饲变京享店夜庙府底剂郊废净" \
+          "盲放刻育闸闹郑券卷单炒炊炕炎炉沫浅法泄河沾泪油泊沿泡注泻泳泥沸波泼泽治怖性怕怜怪学宝宗定宜审宙官空帘" \
+          "实试郎诗肩房诚衬衫视话诞询该详建肃录隶居届刷屈弦承孟孤陕降限妹姑姐姓始驾参艰线练组细驶织终驻驼绍经贯" \
+          "奏春帮珍玻毒型挂封持项垮挎城挠政赴赵挡挺括拴拾挑指垫挣挤拼挖按挥挪某甚革荐巷带草茧茶荒茫荡荣故胡南药" \
+          "标枯柄栋相查柏柳柱柿栏树要咸威歪研砖厘厚砌砍面耐耍牵残殃轻鸦皆背战点临览竖省削尝是盼眨哄显哑冒映星昨" \
+          "畏趴胃贵界虹虾蚁思蚂虽品咽骂哗咱响哈咬咳哪炭峡罚贱贴骨钞钟钢钥钩卸缸拜看矩怎牲选适秒香种秋科重复竿段" \
+          "便俩贷顺修保促侮俭俗俘信皇泉鬼侵追俊盾待律很须叙剑逃食盆胆胜胞胖脉勉狭狮独狡狱狠贸怨急饶蚀饺饼弯将奖" \
+          "哀亭亮度迹庭疮疯疫疤姿亲音帝施闻阀阁差养美姜叛送类迷前首逆总炼炸炮烂剃洁洪洒浇浊洞测洗活派洽染济洋洲" \
+          "浑浓津恒恢恰恼恨举觉宣室宫宪突穿窃客冠语扁袄祖神祝误诱说诵垦退既屋昼费陡眉孩除险院娃姥姨姻娇怒架贺盈" \
+          "勇怠柔垒绑绒结绕骄绘给络骆绝绞统耕耗艳泰珠班素蚕顽盏匪捞栽捕振载赶起盐捎捏埋捉捆捐损都哲逝捡换挽热恐" \
+          "壶挨耻耽恭莲莫荷获晋恶真框桂档桐株桥桃格校核样根索哥速逗栗配翅辱唇夏础破原套逐烈殊顾轿较顿毙致柴桌虑" \
+          "监紧党晒眠晓鸭晃晌晕蚊哨哭恩唤啊唉罢峰圆贼贿钱钳钻铁铃铅缺氧特牺造乘敌秤租积秧秩称秘透笔笑笋债借值倚" \
+          "倾倒倘俱倡候俯倍倦健臭射躬息徒徐舰舱般航途拿爹爱颂翁脆脂胸胳脏胶脑狸狼逢留皱饿恋桨浆衰高席准座脊症病" \
+          "疾疼疲效离唐资凉站剖竞部旁旅畜阅羞瓶兼烤烘烦烧烛烟递涛浙涝酒涉消浩海涂浴浮流润浪浸涨烫涌悟悄悔悦害宽" \
+          "家宵宴宾窄容宰案请朗诸读扇袜袖袍被祥课谁调冤谅谈谊剥恳展弱陵陶陷陪娱娘通能难预桑绢绣验继球理捧堵描域" \
+          "掩捷排掉堆推掀授教掏掠培接控探据掘职基著勒黄萌萝菌菜萄菊萍菠营械梦梢梅检梳梯副票戚爽聋袭盛雪辅辆虚雀" \
+          "堂常匙晨睁眯眼悬野啦晚啄距跃略蛇累唱患唯崖崭崇圈铜铲银甜梨犁移笨笼笛符第敏做袋悠偿偶偷您售停偏假盘船" \
+          "斜盒鸽悉欲彩领脚脖脸脱象够猜猪猎猫猛馅馆凑减毫麻痒痕廊康庸鹿盗章竟商族旋望率着盖粘粗粒断剪兽清添淋淹" \
+          "渠渐混渔淘液淡深渗情惜惭悼惧惕惊惨惯寇寄宿窑密谋谎祸谜逮敢屠弹随蛋隆隐婚婶颈绩绪续骑绳维绵绸绿琴斑替" \
+          "款堪搭塔越趁趋超提堤博揭喜插揪搜煮援搂搅握揉斯期欺联散惹葬葛董葡敬葱落朝辜葵棒棋植森椅椒棵棍棉棚棕惠" \
+          "惑逼厨厦硬确雁殖裂雄暂雅辈悲紫辉敞赏掌晴暑最量喷晶喇遇喊跌跑遗蛙蛛蜓喝喂喘喉幅帽赌赔黑铸铺链销锁锄锅" \
+          "锈锋锐短智毯鹅剩稍程稀税筐等筑策筛筒答筋筝傲傅牌堡集焦傍储奥街惩御循艇舒番释脾腔鲁猾猴然馋装蛮就痛童" \
+          "阔善羡普粪尊道曾焰港湖渣湿温渴滑湾渡游滋溉愤慌惰愧愉慨割寒富窜窝窗遍裕裤裙谢谣谦属屡强粥疏隔隙絮缎缓" \
+          "编骗缘瑞魂肆摄摸填搏塌鼓摆携搬摇搞塘摊蒜勤鹊蓝墓幕蓬蓄蒙蒸献禁楚想槐榆楼概赖酬感碍碑碎碰碗碌雷零雾雹" \
+          "输督龄鉴睛睡睬鄙盟歇暗照跨跳跪路跟遣蛾蜂嗓置罪罩错锡锣锤锦键锯矮辞稠愁筹签简毁舅鼠催傻像躲微愈遥腰腥" \
+          "腹腾腿触解酱痰廉新韵意粮数煎塑慈煤煌源滤滥滔溪溜滚滨粱滩慎誉塞谨福群殿辟障嫌嫁叠缝缠静碧璃墙撇嘉摧截" \
+          "誓境摘摔聚蔽慕暮蔑模榴榜榨歌遭酷酿酸磁愿需弊裳颗嗽蜻蜡蝇锹锻舞稳算箩管僚鼻魄貌膜膊膀鲜疑馒裹敲豪膏遮" \
+          "腐瘦辣竭端旗精歉熄熔漆漂漫滴演漏慢寨赛察蜜谱嫩翠熊凳骡缩慧撕撒趣趟撑播撞撤增蕉蔬横槽樱橡飘醋醉震霉瞒" \
+          "题暴瞎影踢踏踩踪蝶蝴嘱墨镇靠稻黎稿稼箱箭篇僵躺僻德艘膝膛熟摩颜毅糊遵潜潮懂额慰劈操燕薯薪薄颠橘整餐嘴" \
+          "蹄器赠默镜赞篮邀衡膨雕磨凝辨辩糖糕燃澡激懒壁避缴戴擦鞠藏霜霞瞧蹈螺穗繁辫赢糟糠燥臂翼骤鞭覆蹦镰翻鹰警" \
+          "攀蹲颤瓣爆疆壤耀嚷籍魔灌蠢霸露料益拳粉剧屑桶救得衔婆梁裁搁景践禽腊嫂登愚暖满漠蜘赚聪鞋融醒躁嚼"
 cn_punctuation = r"""。？！，、；：“”‘’『』「」（）[]〔〕【】——……·—-～《》〈〉___/"""
 
 
@@ -396,6 +409,61 @@ m_string = StringM()
 
 
 class DateM:
+    @classmethod
+    def datetime_calculate(cls, date_time, time_interval, format_str=None):
+        """
+
+        :param date_time: 需要计算的日期时间
+        :param time_interval: 时间的计算量,例如:'+1min'
+        :param format_str: 时间的格式
+        :return:
+        """
+        # 定义初始化变量
+        days = 0
+        seconds = 0
+        microseconds = 0
+        milliseconds = 0
+        minutes = 0
+        hours = 0
+        month = 0
+        calculate = time_interval[:1]
+        # 正则获取时间单位
+        regular = '[a-zA-Z]+'  # 正则匹配英文
+        match = re.search(regular, time_interval)
+        group = match.group(0)
+        # 时间的单位:天/月/年
+        unit = group
+        # 时间的计算量
+        amount = int(time_interval[1:-len(unit)])
+        # 处理时间的量
+        if 'hours'.startswith(unit):
+            hours = amount
+        elif 'minutes'.startswith(unit):
+            minutes = amount
+        elif 'milliseconds'.startswith(unit):
+            milliseconds = amount
+        elif 'microseconds'.startswith(unit):
+            microseconds = amount
+        elif 'seconds'.startswith(unit):
+            seconds = amount
+        elif 'days'.startswith(unit):
+            days = amount
+        elif 'month'.startswith(unit):
+            month = amount
+            data_result = (date_time + relativedelta(months=month)).strftime(format_str)
+            return data_result
+        elif 'week'.startswith(unit):
+            data_result = (date_time + relativedelta(weeks=amount)).strftime(format_str)
+            return data_result
+        timedelta_value = timedelta(days=days, seconds=seconds, microseconds=microseconds,
+                                    milliseconds=milliseconds, minutes=minutes, hours=hours)
+        if calculate == '+':
+            data_result = (date_time + timedelta_value).strftime(format_str)
+            return data_result
+        elif calculate == '-':
+            data_result = (date_time - timedelta_value).strftime(format_str)
+            return data_result
+
     @classmethod
     def datetime(cls, format_str=None, time_interval: str = None):
         """
@@ -414,48 +482,14 @@ class DateM:
         # '@date("%Y.%m.%d %H:%M:%S","+1")'
         if inNone(format_str):
             format_str = '%Y-%m-%d %H:%M:%S'
-        # 定义初始化变量
-        days = 0
-        seconds = 0
-        microseconds = 0
-        milliseconds = 0
-        minutes = 0
-        hours = 0
         # 当前时间
         curr_time = datetime.now()
-        today = (curr_time.strftime(format_str))
+        today = curr_time.strftime(format_str)
         # 处理时间的计算
         if not inNone(time_interval):
-            calculate = time_interval[:1]
-            # 正则获取时间单位
-            regular = '[a-zA-Z]+'  # 正则匹配英文
-            match = re.search(regular, time_interval)
-            group = match.group(0)
-            unit = group
-            # 时间的间隔量
-            amount = int(time_interval[1:-len(unit)])
-            # 处理时间的量
-            if 'hours'.startswith(unit):
-                hours = amount
-            elif 'minutes'.startswith(unit):
-                minutes = amount
-            elif 'milliseconds'.startswith(unit):
-                milliseconds = amount
-            elif 'microseconds'.startswith(unit):
-                microseconds = amount
-            elif 'seconds'.startswith(unit):
-                seconds = amount
-            elif 'days'.startswith(unit):
-                days = amount
-            timedelta_value = timedelta(days=days, seconds=seconds, microseconds=microseconds,
-                                        milliseconds=milliseconds, minutes=minutes, hours=hours)
-            if calculate == '+':
-                random_data = (curr_time + timedelta_value).strftime(format_str)
-                return random_data
-            elif calculate == '-':
-                random_data = (curr_time - timedelta_value).strftime(format_str)
-                return random_data
-        return today
+            return cls.datetime_calculate(curr_time, time_interval, format_str)
+        else:
+            return today
 
     @classmethod
     def date(cls, format_str=None, time_interval: str = None):
@@ -467,7 +501,7 @@ class DateM:
         可以传参'%Y-%m-%d %H:%M:%S'
         :param format_str:'%Y-%m-%d';'%Y:%m:%d'/'%Y-%m-%d %H:%M:%S'
         :param time_interval: 加或减
-        :return: 随机日期(年月日/年月日时分秒)
+        :return: 随机日期(年月日/年月日时分秒),默认:2023-02-27
         """
         format_str = '%Y-%m-%d' if inNone(format_str) else format_str
         return cls.datetime(format_str, time_interval)
@@ -482,18 +516,78 @@ class DateM:
         可以传参'%Y-%m-%d %H:%M:%S'
         :param time_interval: 加或减
         :param format_str:'%H:%M:%S'/'%Y:%m:%d';'%Y-%m-%d %H:%M:%S'
-        :return: 随机日期(时分秒/年月日时分秒)
+        :return: 随机日期(时分秒/年月日时分秒),默认:21:43:47
         """
         format_str = '%H:%M:%S' if inNone(format_str) else format_str
         return cls.datetime(format_str, time_interval=time_interval)
 
+    @staticmethod
+    def get_current_week(date=None, format_str='%Y-%m-%d'):
+        """
+
+        :param format_str:
+        :param date: "2023-02-19",默认当前日期
+        :return: 指定日期所在周的的元祖:(周一的日期,周日的日期)
+        """
+        if date:
+            duty_date = datetime.strptime(str(date), format_str)
+            monday, sunday = duty_date, duty_date
+        else:
+            monday, sunday = datetime.today(), datetime.today()
+        one_day = timedelta(days=1)
+        while monday.weekday() != 0:
+            monday -= one_day
+        while sunday.weekday() != 6:
+            sunday += one_day
+        # return monday, sunday
+        # 返回时间字符串
+        return datetime.strftime(monday, format_str), datetime.strftime(sunday, format_str)
+
+    @classmethod
+    def now(cls, unit: str = None, format_str='%Y-%m-%d %H:%M:%S'):
+        """
+
+        :param unit: 日期单位
+        :param format_str: 
+        :return: 当前时间:2023-02-27 21:43:47
+        """
+        default_format_str = '%Y-%m-%d %H:%M:%S'
+        now = cls.date(format_str='%Y') + '-01-01 00:00:00'
+        if unit == 'year':
+            return datetime.strptime(now, default_format_str).strftime(format_str)
+        elif unit == 'month':
+            return datetime.strptime(cls.date(format_str='%Y-%m') + '-01 00:00:00', default_format_str).strftime(
+                format_str)
+        elif unit == 'week':
+            # 当前日期的周日所在的日期
+            return datetime.strptime(cls.get_current_week()[1] + ' 00:00:00', default_format_str).strftime(format_str)
+        elif unit == 'day':
+            return datetime.strptime(cls.date(format_str='%Y-%m-%d') + ' 00:00:00', default_format_str).strftime(
+                format_str)
+        elif unit == 'hour':
+            return datetime.strptime(cls.date(format_str='%Y-%m-%d  %H') + ':00:00', default_format_str).strftime(
+                format_str)
+        elif unit == 'minute':
+            return datetime.strptime(cls.date(format_str='%Y-%m-%d  %H:%M') + ':00', default_format_str).strftime(
+                format_str)
+        elif unit == 'second':
+            return cls.datetime(format_str=format_str)
+        elif unit is None:
+            return cls.datetime(format_str=format_str)
+
 
 m_date = DateM()
 
 
 class HelperM:
+
     @classmethod
     def pick(cls, pick_list):
+        """
+        选择集合数据中的一个
+        :param pick_list: 字符串/列表/元祖
+        :return:
+        """
         if inNone(pick_list):
             raise MockPyExpressionException('pick_list cannot be empty.')
         assert isinstance(pick_list, (str, list, tuple))
@@ -506,6 +600,43 @@ m_helper = HelperM()
 
 
 class NameM:
+    """
+    生成随机姓名
+    """
+
+    @classmethod
+    def first(cls):
+        """
+
+        :return: 获取中文姓名的首个字符-姓
+        """
+        return random.choice(en_family_name)
+
+    @classmethod
+    def last(cls):
+        """
+
+        :return: 获取中文姓名的首个字符-名
+        """
+        return random.choice(en_name)
+
+    @classmethod
+    def name(cls, middle=None):
+        """
+
+        :return: 中文姓氏
+        """
+        if middle is not None and middle in ('true', 'True', True, '1', 1):
+            a = cls.first()
+            c = cls.last()
+            b = None
+            for i in range(20):
+                b = cls.first()
+                if cls.first() != a:
+                    break
+            return f'{a} {b} {c}'
+        return f'{cls.first()} {cls.last()}'
+
     @classmethod
     def cfirst(cls):
         """
@@ -531,7 +662,18 @@ class NameM:
         length = random.randint(2, 3) if length is None else length
         if 3 <= length < 2:
             raise MockPyExpressionException()
-        return cls.cfirst() + m_string.chinese(length - 1)
+        cname = cls.cfirst() + m_string.chinese(length - 1)
+        # assert not '\n' in cname
+        return cname
 
 
 m_name = NameM()
+
+# class ImageM:
+#     @classmethod
+#     def image(cls):
+#         img = Image.new("RGB", (200, 300), (0, 0, 0))  # 8*8像素
+#         img.save("./black.png")
+#
+#
+# m_image = ImageM()
